/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.mapper.xcontent.geo;

import org.elasticsearch.common.unit.DistanceUnit;
import org.elasticsearch.index.field.data.DocFieldData;

/**
 * @author kimchy (shay.banon)
 */
public class GeoPointDocFieldData extends DocFieldData<GeoPointFieldData> {

    public GeoPointDocFieldData(GeoPointFieldData fieldData) {
        super(fieldData);
    }

    public GeoPoint getValue() {
        return fieldData.value(docId);
    }

    public GeoPoint[] getValues() {
        return fieldData.values(docId);
    }

    public double distance(double lat, double lon) {
        return fieldData.distance(docId, DistanceUnit.MILES, lat, lon);
    }

    public double distanceInKm(double lat, double lon) {
        return fieldData.distance(docId, DistanceUnit.KILOMETERS, lat, lon);
    }

    public double geohashDistance(String geohash) {
        return fieldData.distanceGeohash(docId, DistanceUnit.MILES, geohash);
    }

    public double geohashDistanceInKm(String geohash) {
        return fieldData.distanceGeohash(docId, DistanceUnit.KILOMETERS, geohash);
    }

    public double getLat() {
        return fieldData.latValue(docId);
    }

    public double getLon() {
        return fieldData.lonValue(docId);
    }

    public double[] getLats() {
        return fieldData.latValues(docId);
    }

    public double[] getLons() {
        return fieldData.lonValues(docId);
    }
}
